@@ -1,6 +1,6 @@
 package Enbld::Archivefile;
 
-use 5.012;
+use strict;
 use warnings;
 
 use Archive::Tar;
@@ -45,7 +45,7 @@ sub _err {
     my ( $err, $msg ) = @_;
 
     require Enbld::Error;
-    die( Enbld::Error->new( $err, $msg ) );
+    Enbld::Error->throw( $err, $msg );
 }
 
 1;
