@@ -1,6 +1,6 @@
 package Enbld::Definition::Vim;
 
-use 5.012;
+use strict;
 use warnings;
 
 use version;
@@ -31,10 +31,7 @@ sub initialize {
     $self->{defined}{Version}           =   \&set_version;
     $self->{defined}{PatchFiles}        =   \&set_patchfiles;
 
-    $self->{defined}{CommandConfigure}  =   'LANG=C;./configure';
-    $self->{defined}{CommandMake}       =   'LANG=C;make';
-    $self->{defined}{CommandTest}       =   'LANG=C;make test';
-    $self->{defined}{CommandInstall}    =   'LANG=C;make install';
+    $self->{defined}{TestAction}        =   'test';
 
     return $self;
 }
